@@ -169,7 +169,7 @@ class Device(object):
         self.vc = ViewClient(self.adbclient, serialno, autodump=False)
 
         def _adb(*args):
-            return subprocess.check_output(['adb', '-s', self._serialno] + list(args))
+            return subprocess.check_output(['adb', '-s', self._serialno] + list(map(str, args)))
         self.adb = _adb
         self.adbshell = partial(_adb, 'shell')
 
@@ -211,13 +211,15 @@ class Device(object):
             raise RuntimeError("No such snapshot method: [%s]" % self._snapshot_method)
 
 
-    def touch(self, x, y, duration=0.1):
+    def touch(self, x, y, duration=None):
         '''
         same as adb -s ${SERIALNO} shell input tap x y
         '''
-        assert duration >= 0
-        self.adbshell(proto.AIRNATIVE, '-runjs', 'tap({x}, {y}, {dur})'.format(
-            x=x, y=y, dur=int(duration*1000)))
+        if not duration:
+            self.adbshell('input', 'tap', x, y)
+        else:
+            self.adbshell(proto.AIRNATIVE, '-runjs', 'tap({x}, {y}, {dur})'.format(
+                x=x, y=y, dur=int(duration*1000)))
 
     def drag(self, (x0, y0), (x1, y1), duration=0.5):
         '''
@@ -227,10 +229,21 @@ class Device(object):
             x0=x0, y0=y0, x1=x1, y1=y1, steps=10, dur=int(duration*1000)))
         # self.adb.drag((x0, y0), (x1, y1), duration)
 
-    @patch.run_once
+    def rotation(self):
+        '''
+        dumpsys ref: http://imsardine.simplbug.com/note/android/adb/commands/dumpsys.html
+        '''
+        patten = re.compile('SurfaceOrientation:\s+(\d+)')
+        output = self.adbshell('dumpsys', 'input')
+        match = patten.search(output)
+        if match:
+            return int(match.group(1))
+        return proto.ROTATION_0
+        # return self.adbclient.getProperty('display.orientation')
+
     def shape(self):
         ''' 
-        Get screen width and height 
+        Get screen width and height, when landscape width > height
         '''
         width = self.adbclient.getProperty("display.width")
         height = self.adbclient.getProperty("display.height")
@@ -281,13 +294,13 @@ class Device(object):
         '''
         self.adbshell('input', 'keyevent', str(event))
 
-    def start_app(self, appname, activity=None):
+    def start_app(self, appname, activity):
         '''
         Start a program
 
         @param extra: dict (defined in air.json)
         '''
-        self.adbshell('am', 'start', '-s', '-N', appname+'/'+activity)
+        self.adbshell('am', 'start', '-n', appname+'/'+activity)
 
     def stop_app(self, appname):
         '''
